diff --git a/ChangeLog b/ChangeLog
index bec8f27..388be65 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1797,7 +1797,7 @@ Sat 30 Mar 2002 12:55:30 AM PST Aleksey Sanin <aleksey@aleksey.com>
     
 Wed 27 Mar 2002 11:20:42 PM PST Aleksey Sanin <aleksey@aleksey.com> 
 	*: Added x509 verification support and a skeleton for x509 
-          x509 based sigantures
+          x509 based signatures
     
 Tue 26 Mar 2002 06:30:10 PM PST Aleksey Sanin <aleksey@aleksey.com>
 	*: The result of operation (sign/verify) is returned in the
diff --git a/configure.in b/configure.in
index 7120258..cea497a 100644
--- a/configure.in
+++ b/configure.in
@@ -76,7 +76,7 @@ dnl ==========================================================================
 AC_MSG_CHECKING(for development environment) 
 AC_ARG_ENABLE(development,   [  --enable-development    enable development environment (no)])
 if test "z$enable_development" = "zyes" ; then
-    enable_debuging="yes"
+    enable_debugging="yes"
     enable_pedantic="yes"
     enable_static_linking="yes"
     enable_crypto_dl="no"
@@ -1089,7 +1089,7 @@ esac
 AC_MSG_RESULT(yes ('$XMLSEC_CRYPTO'))
 
 dnl ==========================================================================
-dnl See do we need MD5 suport
+dnl See do we need MD5 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for MD5 support) 
 AC_ARG_ENABLE(md5,   [  --enable-md5            enable MD5 support (yes)])
@@ -1105,7 +1105,7 @@ AM_CONDITIONAL(XMLSEC_NO_MD5, test "z$XMLSEC_NO_MD5" = "z1")
 AC_SUBST(XMLSEC_NO_MD5)
 
 dnl ==========================================================================
-dnl See do we need RIPEMD-160 suport
+dnl See do we need RIPEMD-160 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for RIPEMD-160 support) 
 AC_ARG_ENABLE(ripemd160,   [  --enable-ripemd160      enable RIPEMD-160 support (yes)])
@@ -1121,7 +1121,7 @@ AM_CONDITIONAL(XMLSEC_NO_RIPEMD160, test "z$XMLSEC_NO_RIPEMD160" = "z1")
 AC_SUBST(XMLSEC_NO_RIPEMD160)
 
 dnl ==========================================================================
-dnl See do we need SHA1 suport
+dnl See do we need SHA1 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for SHA1 support) 
 AC_ARG_ENABLE(sha1,   [  --enable-sha1           enable SHA1 support (yes)])
@@ -1137,7 +1137,7 @@ AM_CONDITIONAL(XMLSEC_NO_SHA1, test "z$XMLSEC_NO_SHA1" = "z1")
 AC_SUBST(XMLSEC_NO_SHA1)
 
 dnl ==========================================================================
-dnl See do we need SHA224 suport
+dnl See do we need SHA224 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for SHA224 support) 
 AC_ARG_ENABLE(sha224,   [  --enable-sha224         enable SHA224 support (yes)])
@@ -1153,7 +1153,7 @@ AM_CONDITIONAL(XMLSEC_NO_SHA224, test "z$XMLSEC_NO_SHA224" = "z1")
 AC_SUBST(XMLSEC_NO_SHA224)
 
 dnl ==========================================================================
-dnl See do we need SHA256 suport
+dnl See do we need SHA256 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for SHA256 support) 
 AC_ARG_ENABLE(sha256,   [  --enable-sha256         enable SHA256 support (yes)])
@@ -1169,7 +1169,7 @@ AM_CONDITIONAL(XMLSEC_NO_SHA256, test "z$XMLSEC_NO_SHA256" = "z1")
 AC_SUBST(XMLSEC_NO_SHA256)
 
 dnl ==========================================================================
-dnl See do we need SHA384 suport
+dnl See do we need SHA384 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for SHA384 support) 
 AC_ARG_ENABLE(sha384,   [  --enable-sha384         enable SHA384 support (yes)])
@@ -1185,7 +1185,7 @@ AM_CONDITIONAL(XMLSEC_NO_SHA384, test "z$XMLSEC_NO_SHA384" = "z1")
 AC_SUBST(XMLSEC_NO_SHA384)
 
 dnl ==========================================================================
-dnl See do we need SHA512 suport
+dnl See do we need SHA512 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for SHA512 support) 
 AC_ARG_ENABLE(sha512,   [  --enable-sha512         enable SHA512 support (yes)])
@@ -1202,7 +1202,7 @@ AC_SUBST(XMLSEC_NO_SHA512)
 
 
 dnl ==========================================================================
-dnl See do we need HMAC suport
+dnl See do we need HMAC support
 dnl ==========================================================================
 AC_MSG_CHECKING(for HMAC support) 
 AC_ARG_ENABLE(hmac,   [  --enable-hmac           enable HMAC support (yes)])
@@ -1218,7 +1218,7 @@ AM_CONDITIONAL(XMLSEC_NO_HMAC, test "z$XMLSEC_NO_HMAC" = "z1")
 AC_SUBST(XMLSEC_NO_HMAC)
 
 dnl ==========================================================================
-dnl See do we need DSA suport
+dnl See do we need DSA support
 dnl ==========================================================================
 AC_MSG_CHECKING(for DSA support) 
 AC_ARG_ENABLE(dsa,   [  --enable-dsa            enable DSA support (yes)])
@@ -1234,7 +1234,7 @@ AM_CONDITIONAL(XMLSEC_NO_DSA, test "z$XMLSEC_NO_DSA" = "z1")
 AC_SUBST(XMLSEC_NO_DSA)
 
 dnl ==========================================================================
-dnl See do we need RSA suport
+dnl See do we need RSA support
 dnl ==========================================================================
 AC_MSG_CHECKING(for RSA support) 
 AC_ARG_ENABLE(rsa,   [  --enable-rsa            enable RSA support (yes)])
@@ -1250,7 +1250,7 @@ AM_CONDITIONAL(XMLSEC_NO_RSA, test "z$XMLSEC_NO_RSA" = "z1")
 AC_SUBST(XMLSEC_NO_RSA)
 
 dnl ==========================================================================
-dnl See do we need x509 suport
+dnl See do we need x509 support
 dnl ==========================================================================
 AC_MSG_CHECKING(for x509 support) 
 AC_ARG_ENABLE(x509,   [  --enable-x509           enable x509 support (yes)])
@@ -1266,7 +1266,7 @@ AM_CONDITIONAL(XMLSEC_NO_X509, test "z$XMLSEC_NO_X509" = "z1")
 AC_SUBST(XMLSEC_NO_X509)
 
 dnl ==========================================================================
-dnl See do we need DES suport
+dnl See do we need DES support
 dnl ==========================================================================
 AC_MSG_CHECKING(for DES support) 
 AC_ARG_ENABLE(des,   [  --enable-des            enable DES support (yes)])
@@ -1282,7 +1282,7 @@ AM_CONDITIONAL(XMLSEC_NO_DES, test "z$XMLSEC_NO_DES" = "z1")
 AC_SUBST(XMLSEC_NO_DES)
 
 dnl ==========================================================================
-dnl See do we need AES suport
+dnl See do we need AES support
 dnl ==========================================================================
 AC_MSG_CHECKING(for AES support) 
 AC_ARG_ENABLE(aes,   [  --enable-aes            enable AES support (OpenSSL >= 0.9.7 is required)])
@@ -1298,7 +1298,7 @@ AM_CONDITIONAL(XMLSEC_NO_AES, test "z$XMLSEC_NO_AES" = "z1")
 AC_SUBST(XMLSEC_NO_AES)
 
 dnl ==========================================================================
-dnl See do we need GOST suport
+dnl See do we need GOST support
 dnl ==========================================================================
 AC_MSG_CHECKING(for GOST support) 
 AC_ARG_ENABLE(gost,   [  --enable-gost           enable GOST support (no)])
@@ -1314,7 +1314,7 @@ AM_CONDITIONAL(XMLSEC_NO_GOST, test "z$XMLSEC_NO_GOST" = "z1")
 AC_SUBST(XMLSEC_NO_GOST)
 
 dnl ==========================================================================
-dnl See do we need XMLDSig suport
+dnl See do we need XMLDSig support
 dnl ==========================================================================
 AC_MSG_CHECKING(for XMLDSig support) 
 AC_ARG_ENABLE(xmldsig,   [  --enable-xmldsig        enable XMLDSig support (yes)])
@@ -1330,7 +1330,7 @@ AM_CONDITIONAL(XMLSEC_NO_XMLDSIG, test "z$XMLSEC_NO_XMLDSIG" = "z1")
 AC_SUBST(XMLSEC_NO_XMLDSIG)
 
 dnl ==========================================================================
-dnl See do we need XMLEnc suport
+dnl See do we need XMLEnc support
 dnl ==========================================================================
 AC_MSG_CHECKING(for XMLEnc support) 
 AC_ARG_ENABLE(xmlenc,   [  --enable-xmlenc         enable XMLEnc support (yes)])
@@ -1346,7 +1346,7 @@ AM_CONDITIONAL(XMLSEC_NO_XMLENC, test "z$XMLSEC_NO_XMLENC" = "z1")
 AC_SUBST(XMLSEC_NO_XMLENC)
 
 dnl ==========================================================================
-dnl See do we need XKMS suport
+dnl See do we need XKMS support
 dnl ==========================================================================
 AC_MSG_CHECKING(for XMKMS support - under development, not stable yet) 
 AC_ARG_ENABLE(xkms,   [  --enable-xkms           enable XKMS support - under development (no)])
@@ -1463,9 +1463,9 @@ fi
 dnl ==========================================================================
 dnl Debug 
 dnl ==========================================================================
-AC_MSG_CHECKING(for debuging) 
-AC_ARG_ENABLE(debuging,   [  --enable-debuging       enable debuging compilation flags (no)])
-if test "z$enable_debuging" = "zyes" ; then
+AC_MSG_CHECKING(for debugging)
+AC_ARG_ENABLE(debugging,   [  --enable-debugging      enable debugging compilation flags (no)])
+if test "z$enable_debugging" = "zyes" ; then
     CFLAGS="$CFLAGS -g"
     AC_MSG_RESULT(yes)
 else
diff --git a/docs/api/chapters/sign-and-encrypt.sgml b/docs/api/chapters/sign-and-encrypt.sgml
index 58ff04a..72b969b 100644
--- a/docs/api/chapters/sign-and-encrypt.sgml
+++ b/docs/api/chapters/sign-and-encrypt.sgml
@@ -20,7 +20,7 @@
     
     <sect1 id="xmlsec-notes-sign" >
 	<title>Signing a document.</title>
-	<para>The typical siganture process includes following steps:
+	<para>The typical signature process includes following steps:
 	  <itemizedlist>
 	    <listitem><para>
 		Prepare data for signature.
diff --git a/docs/api/chapters/using-contexts.sgml b/docs/api/chapters/using-contexts.sgml
index 0dc1c26..48a336d 100644
--- a/docs/api/chapters/using-contexts.sgml
+++ b/docs/api/chapters/using-contexts.sgml
@@ -71,13 +71,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     /* limit the Reference URI attributes to empty or NULL */
     dsigCtx->enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
-    /* limit allowed transforms for siganture and reference processing */
+    /* limit allowed transforms for signature and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformSha1Id) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformRsaSha1Id) < 0)) {
 
-        fprintf(stderr,"Error: failed to limit allowed siganture transforms\n");
+        fprintf(stderr,"Error: failed to limit allowed signature transforms\n");
 	goto done;
     }
     if((xmlSecDSigCtxEnableReferenceTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
diff --git a/docs/api/chapters/verify-and-decrypt.sgml b/docs/api/chapters/verify-and-decrypt.sgml
index 699d19b..382c97c 100644
--- a/docs/api/chapters/verify-and-decrypt.sgml
+++ b/docs/api/chapters/verify-and-decrypt.sgml
@@ -20,7 +20,7 @@
     
     <sect1 id="xmlsec-notes-verify" >
 	<title>Verifying a signed document</title>
-	<para>The typical siganture verification process includes following steps:
+	<para>The typical signature verification process includes following steps:
 	  <itemizedlist>
 	    <listitem><para>
 		Load keys, X509 certificates, etc. in the <link linkend="xmlSecKeysMngr">keys manager</link> .
diff --git a/docs/api/sgml/xmldsig.sgml b/docs/api/sgml/xmldsig.sgml
index e66705f..b9d52fc 100644
--- a/docs/api/sgml/xmldsig.sgml
+++ b/docs/api/sgml/xmldsig.sgml
@@ -85,7 +85,7 @@ XML Digital signature processing status.
 </para><variablelist role="enum">
 <varlistentry id="xmlSecDSigStatusUnknown" role="constant">
 <term><literal>xmlSecDSigStatusUnknown</literal></term>
-<listitem><simpara>the status is unknow.
+<listitem><simpara>the status is unknown.
 </simpara></listitem>
 </varlistentry>
 <varlistentry id="xmlSecDSigStatusSucceeded" role="constant">
@@ -243,11 +243,11 @@ XML DSig processing context.
 </simpara></listitem>
 </varlistentry>
 <varlistentry><term><link linkend="xmlSecBuffer"><type>xmlSecBufferPtr</type></link>&#160;<structfield id="xmlSecDSigCtx.result">result</structfield>;</term>
-<listitem><simpara>the pointer to signature (not valid for signature verificaction).
+<listitem><simpara>the pointer to signature (not valid for signature verification).
 </simpara></listitem>
 </varlistentry>
 <varlistentry><term><link linkend="xmlSecDSigStatus"><type>xmlSecDSigStatus</type></link>&#160;<structfield id="xmlSecDSigCtx.status">status</structfield>;</term>
-<listitem><simpara>the <ulink URL="http://www.w3.org/TR/xmldsig-core/#sec-Signatuire">&lt;dsig:Signatuire/&gt;</ulink> procesisng status.
+<listitem><simpara>the <ulink URL="http://www.w3.org/TR/xmldsig-core/#sec-Signatuire">&lt;dsig:Signatuire/&gt;</ulink> processing status.
 </simpara></listitem>
 </varlistentry>
 <varlistentry><term><link linkend="xmlSecTransform"><type>xmlSecTransformPtr</type></link>&#160;<structfield id="xmlSecDSigCtx.signMethod">signMethod</structfield>;</term>
diff --git a/docs/api/sgml/xmlenc.sgml b/docs/api/sgml/xmlenc.sgml
index b2320e2..9c46a63 100644
--- a/docs/api/sgml/xmlenc.sgml
+++ b/docs/api/sgml/xmlenc.sgml
@@ -171,7 +171,7 @@ XML Encrypiton context.
 </simpara></listitem>
 </varlistentry>
 <varlistentry><term><link linkend="xmlSecBuffer"><type>xmlSecBufferPtr</type></link>&#160;<structfield id="xmlSecEncCtx.result">result</structfield>;</term>
-<listitem><simpara>the pointer to signature (not valid for signature verificaction).
+<listitem><simpara>the pointer to signature (not valid for signature verification).
 </simpara></listitem>
 </varlistentry>
 <varlistentry><term><link linkend="int"><type>int</type></link>&#160;<structfield id="xmlSecEncCtx.resultBase64Encoded">resultBase64Encoded</structfield>;</term>
diff --git a/docs/api/xmlsec-notes-contexts.html b/docs/api/xmlsec-notes-contexts.html
index 247f83f..21d879f 100644
--- a/docs/api/xmlsec-notes-contexts.html
+++ b/docs/api/xmlsec-notes-contexts.html
@@ -157,13 +157,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     /* limit the Reference URI attributes to empty or NULL */
     dsigCtx-&gt;enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
-    /* limit allowed transforms for siganture and reference processing */
+    /* limit allowed transforms for signature and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformSha1Id) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformRsaSha1Id) &lt; 0)) {
 
-        fprintf(stderr,"Error: failed to limit allowed siganture transforms\n");
+        fprintf(stderr,"Error: failed to limit allowed signature transforms\n");
 	goto done;
     }
     if((xmlSecDSigCtxEnableReferenceTransform(dsigCtx, xmlSecTransformInclC14NId) &lt; 0) ||
diff --git a/docs/api/xmlsec-notes-sign.html b/docs/api/xmlsec-notes-sign.html
index 4e746c6..5ba58e4 100644
--- a/docs/api/xmlsec-notes-sign.html
+++ b/docs/api/xmlsec-notes-sign.html
@@ -86,7 +86,7 @@
 </tr></table>
 <br clear="all"><div class="SECT1">
 <h1 class="SECT1"><a name="XMLSEC-NOTES-SIGN">Signing a document.</a></h1>
-<p>The typical siganture process includes following steps:
+<p>The typical signature process includes following steps:
 	  </p>
 <p></p>
 <ul>
diff --git a/docs/api/xmlsec-notes-verify.html b/docs/api/xmlsec-notes-verify.html
index 05a95fb..da3847f 100644
--- a/docs/api/xmlsec-notes-verify.html
+++ b/docs/api/xmlsec-notes-verify.html
@@ -86,7 +86,7 @@
 </tr></table>
 <br clear="all"><div class="SECT1">
 <h1 class="SECT1"><a name="XMLSEC-NOTES-VERIFY">Verifying a signed document</a></h1>
-<p>The typical siganture verification process includes following steps:
+<p>The typical signature verification process includes following steps:
 	  </p>
 <p></p>
 <ul>
diff --git a/docs/api/xmlsec-verify-with-restrictions.html b/docs/api/xmlsec-verify-with-restrictions.html
index b910c13..e1c47f2 100644
--- a/docs/api/xmlsec-verify-with-restrictions.html
+++ b/docs/api/xmlsec-verify-with-restrictions.html
@@ -339,13 +339,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     /* limit the Reference URI attributes to empty or NULL */
     dsigCtx-&gt;enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
-    /* limit allowed transforms for siganture and reference processing */
+    /* limit allowed transforms for signature and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformSha1Id) &lt; 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformRsaSha1Id) &lt; 0)) {
 
-        fprintf(stderr,"Error: failed to limit allowed siganture transforms\n");
+        fprintf(stderr,"Error: failed to limit allowed signature transforms\n");
         goto done;
     }
     if((xmlSecDSigCtxEnableReferenceTransform(dsigCtx, xmlSecTransformInclC14NId) &lt; 0) ||
diff --git a/docs/api/xmlsec-xmldsig.html b/docs/api/xmlsec-xmldsig.html
index af6c63f..91cfef3 100644
--- a/docs/api/xmlsec-xmldsig.html
+++ b/docs/api/xmlsec-xmldsig.html
@@ -155,7 +155,7 @@ struct              <a href="xmlsec-xmldsig.html#XMLSECDSIGREFERENCECTX">xmlSecD
 <table class="variablelist" border="0" cellspacing="0" cellpadding="4"><tbody>
 <tr>
 <td align="LEFT" valign="TOP"><a name="XMLSECDSIGSTATUSUNKNOWN"><span style="white-space: nowrap"><tt class="LITERAL">xmlSecDSigStatusUnknown</tt></span></a></td>
-<td align="LEFT" valign="TOP"><p>the status is unknow.</p></td>
+<td align="LEFT" valign="TOP"><p>the status is unknown.</p></td>
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="XMLSECDSIGSTATUSSUCCEEDED"><span style="white-space: nowrap"><tt class="LITERAL">xmlSecDSigStatusSucceeded</tt></span></a></td>
@@ -301,11 +301,11 @@ documents that don't follow XML, XPointer and XML DSig specifications.</p>
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="AEN21595"><span style="white-space: nowrap"><a href="xmlsec-buffer.html#XMLSECBUFFER"><span class="TYPE">xmlSecBufferPtr</span></a> <code class="STRUCTFIELD">result</code>;</span></a></td>
-<td align="LEFT" valign="TOP"><p>the pointer to signature (not valid for signature verificaction).</p></td>
+<td align="LEFT" valign="TOP"><p>the pointer to signature (not valid for signature verification).</p></td>
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="AEN21602"><span style="white-space: nowrap"><a href="xmlsec-xmldsig.html#XMLSECDSIGSTATUS"><span class="TYPE">xmlSecDSigStatus</span></a> <code class="STRUCTFIELD">status</code>;</span></a></td>
-<td align="LEFT" valign="TOP"><p>the <a href="http://www.w3.org/TR/xmldsig-core/#sec-Signatuire" target="_top">&lt;dsig:Signatuire/&gt;</a> procesisng status.</p></td>
+<td align="LEFT" valign="TOP"><p>the <a href="http://www.w3.org/TR/xmldsig-core/#sec-Signatuire" target="_top">&lt;dsig:Signatuire/&gt;</a> processing status.</p></td>
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="AEN21610"><span style="white-space: nowrap"><a href="xmlsec-transforms.html#XMLSECTRANSFORM"><span class="TYPE">xmlSecTransformPtr</span></a> <code class="STRUCTFIELD">signMethod</code>;</span></a></td>
diff --git a/docs/api/xmlsec-xmlenc.html b/docs/api/xmlsec-xmlenc.html
index 9d6dcb6..fbcf9f5 100644
--- a/docs/api/xmlsec-xmlenc.html
+++ b/docs/api/xmlsec-xmlenc.html
@@ -238,7 +238,7 @@ struct              <a href="xmlsec-xmlenc.html#XMLSECENCCTX">xmlSecEncCtx</a>;
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="AEN22635"><span style="white-space: nowrap"><a href="xmlsec-buffer.html#XMLSECBUFFER"><span class="TYPE">xmlSecBufferPtr</span></a> <code class="STRUCTFIELD">result</code>;</span></a></td>
-<td align="LEFT" valign="TOP"><p>the pointer to signature (not valid for signature verificaction).</p></td>
+<td align="LEFT" valign="TOP"><p>the pointer to signature (not valid for signature verification).</p></td>
 </tr>
 <tr>
 <td align="LEFT" valign="TOP"><a name="AEN22642"><span style="white-space: nowrap"><gtkdoclink href="INT"><span class="TYPE">int</span></gtkdoclink> <code class="STRUCTFIELD">resultBase64Encoded</code>;</span></a></td>
diff --git a/include/xmlsec/xmldsig.h b/include/xmlsec/xmldsig.h
index 689980b..3cd311e 100644
--- a/include/xmlsec/xmldsig.h
+++ b/include/xmlsec/xmldsig.h
@@ -36,7 +36,7 @@ typedef struct _xmlSecDSigReferenceCtx          xmlSecDSigReferenceCtx,
 
 /**
  * xmlSecDSigStatus:
- * @xmlSecDSigStatusUnknown:    the status is unknow.
+ * @xmlSecDSigStatusUnknown:    the status is unknown.
  * @xmlSecDSigStatusSucceeded:  the processing succeeded.
  * @xmlSecDSigStatusInvalid:    the processing failed.
  *
@@ -113,8 +113,8 @@ typedef enum {
  *                              before calling #xmlSecDSigCtxSign or #xmlSecDSigCtxVerify
  *                              functions.
  * @operation:                  the operation: sign or verify.
- * @result:                     the pointer to signature (not valid for signature verificaction).
- * @status:                     the <dsig:Signatuire/> procesisng status.
+ * @result:                     the pointer to signature (not valid for signature verification).
+ * @status:                     the <dsig:Signatuire/> processing status.
  * @signMethod:                 the pointer to signature transform.
  * @c14nMethod:                 the pointer to c14n transform.
  * @preSignMemBufMethod:        the pointer to binary buffer right before signature
diff --git a/include/xmlsec/xmlenc.h b/include/xmlsec/xmlenc.h
index 8f97277..6725454 100644
--- a/include/xmlsec/xmlenc.h
+++ b/include/xmlsec/xmlenc.h
@@ -64,7 +64,7 @@ typedef enum {
  * @encKey:                     the signature key; application may set #encKey
  *                              before calling encryption/decryption functions.
  * @operation:                  the operation: encrypt or decrypt.
- * @result:                     the pointer to signature (not valid for signature verificaction).
+ * @result:                     the pointer to signature (not valid for signature verification).
  * @resultBase64Encoded:        the flag: if set then result in #result is base64 encoded.
  * @resultReplaced:             the flag: if set then resulted <enc:EncryptedData/>
  *                              or <enc:EncryptedKey/> node is added to the document.
diff --git a/win32/configure.js b/win32/configure.js
index c5551f1..1d3622c 100644
--- a/win32/configure.js
+++ b/win32/configure.js
@@ -382,7 +382,7 @@ txtOut += "-------------------------\n";
 txtOut += "           Unicode: " + boolToStr(buildUnicode) + "\n";
 txtOut += "     Debug symbols: " + boolToStr(buildDebug) + "\n";
 txtOut += "     Static xmlsec: " + boolToStr(buildStatic) + "\n";
-txtOut += "  Enable DL suport: " + boolToStr(buildWithDLSupport) + "\n";
+txtOut += " Enable DL support: " + boolToStr(buildWithDLSupport) + "\n";
 txtOut += "    Install prefix: " + buildPrefix + "\n";
 txtOut += "      Put tools in: " + buildBinPrefix + "\n";
 txtOut += "    Put headers in: " + buildIncPrefix + "\n";

diff --git a/examples/verify4.c b/examples/verify4.c
index 1445e99..f55f58c 100644
--- a/examples/verify4.c
+++ b/examples/verify4.c
@@ -246,13 +246,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     /* limit the Reference URI attributes to empty or NULL */
     dsigCtx->enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
     /* limit allowed transforms for siganture and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformSha1Id) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformRsaSha1Id) < 0)) {
 
-        fprintf(stderr,"Error: failed to limit allowed siganture transforms\n");
+        fprintf(stderr,"Error: failed to limit allowed signature transforms\n");
         goto done;
     }
     if((xmlSecDSigCtxEnableReferenceTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
@@ -246,13 +246,13 @@ verify_file(xmlSecKeysMngrPtr mngr, const char* xml_file) {
     dsigCtx->enabledReferenceUris = xmlSecTransformUriTypeEmpty;
     
-    /* limit allowed transforms for siganture and reference processing */
+    /* limit allowed transforms for signature and reference processing */
     if((xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformInclC14NId) < 0) ||
        (xmlSecDSigCtxEnableSignatureTransform(dsigCtx, xmlSecTransformExclC14NId) < 0) ||
diff --git a/src/xmldsig.c b/src/xmldsig.c
index cec9ca6..b08b8b1 100644
--- a/src/xmldsig.c
+++ b/src/xmldsig.c
@@ -302,7 +302,7 @@ xmlSecDSigCtxSign(xmlSecDSigCtxPtr dsigCtx, xmlNodePtr tmpl) {
     if(ret < 0) {
         xmlSecError(XMLSEC_ERRORS_HERE,
                     NULL,
-                    "xmlSecDSigCtxSigantureProcessNode",
+                    "xmlSecDSigCtxSignatureProcessNode",
                     XMLSEC_ERRORS_R_XMLSEC_FAILED,
                     XMLSEC_ERRORS_NO_MESSAGE);
         return(-1);
@@ -360,12 +360,12 @@ xmlSecDSigCtxVerify(xmlSecDSigCtxPtr dsigCtx, xmlNodePtr node) {
     dsigCtx->status     = xmlSecDSigStatusUnknown;
     xmlSecAddIDs(node->doc, node, xmlSecDSigIds);
 
     /* read siganture info */
     ret = xmlSecDSigCtxProcessSignatureNode(dsigCtx, node);
     if(ret < 0) {
         xmlSecError(XMLSEC_ERRORS_HERE,
                     NULL,
-                    "xmlSecDSigCtxSigantureProcessNode",
+                    "xmlSecDSigCtxSignatureProcessNode",
                     XMLSEC_ERRORS_R_XMLSEC_FAILED,
                     XMLSEC_ERRORS_NO_MESSAGE);
         return(-1);
@@ -360,12 +360,12 @@ xmlSecDSigCtxVerify(xmlSecDSigCtxPtr dsigCtx, xmlNodePtr node) {
     xmlSecAddIDs(node->doc, node, xmlSecDSigIds);
 
-    /* read siganture info */
+    /* read signature info */
     ret = xmlSecDSigCtxProcessSignatureNode(dsigCtx, node);
     if(ret < 0) {